
#include<stdio.h>
#include<string.h>
#include<stdlib.h>

#include"sitar_scan.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"




/*----------------- SCAN HOST --------------------*/
char * scan_host(char * ip_data, char * ip_addr, char * backdata, int timeout, int * stat)
{
unsigned long addr;
unsigned char inip_addr[4];
char ch[256];
char * ch_addr = ch;

memset(ch_addr, 0x00, 256);

backdata = resolvename(backdata, ip_addr, timeout, &addr);

memcpy(inip_addr, &addr, sizeof(inip_addr));

sprintf(ch_addr,"%d.%d.%d.%d",
  inip_addr[0],
  inip_addr[1],
  inip_addr[2],
  inip_addr[3]
  );

if(0 == (int)addr){
   backdata = safe_sprintf(backdata, BUF_MAX, "%s %s %s\n", SOCK_2, ip_addr, ch_addr);
   #ifdef HOST_BUG
   printf("HOST: scan_host(1): NOT RESOLV NAME %s\n", backdata);
   #endif
   * stat = -1;
   return backdata;
   }
else{
   if(0 == self_memcmp(ch_addr, ip_data)){
      backdata = safe_sprintf(backdata, BUF_MAX, "%s %s %s == %s\n", SOCK_8, ip_addr, ch_addr, ip_data);
      #ifdef HOST_BUG
      printf("HOST: scan_host(2): RESOLV NAME %s\n", backdata);
      #endif
      * stat = 1;
      return backdata;
      }
   else{
      backdata = safe_sprintf(backdata, BUF_MAX, "%s %s %s != %s\n", SOCK_9, ip_addr, ch_addr, ip_data);
      #ifdef HOST_BUG
      printf("HOST: scan_host(3): RESOLV NAME %s\n", backdata);
      #endif
      * stat = -1;
      return backdata;
      }
   }

* stat = 1;
return backdata;
}






